#  Copyright (C) 2023
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Revva Konstantin <k.revva@abm-jsc.ru>


from shift_detector_connector.shift_analyze_result import ShiftAnalyzeResult
from shift_detector_connector.shift_detector_connector import ShiftDetectorConnector
from detector_connector import DetectorHttpConnector as ShiftDetectorHttpConnector
from shift_detector_connector.shift_detector_kafka_connector import ShiftDetectorKafkaConnector
